/* oms-maxp.h --- header file shared between driver and user-space
 *    programs.  Defines the physical MAXp hardware I/O.
 *
 *
 *  Copyright(c) 2003 Oregon Micro Systems, Inc.  All rights reserved.
 */

#ifndef __OMSMAXP_H_
#define __OMSMAXP_H_

#include "oms.h"	// core IOCTL calls, et. al.

//****************************************************************************
// HARDWARE SPECIFIC REGISTER AND BIT DEFINITIONS

// control and status bits
#define CMDERR_BIT              0x01  //Command error
#define INIT_BIT                0x02  //Controller is initializing
#define SLIP_BIT                0x04  //Axis encoder slip
#define OVRT_BIT                0x08  //Axis overtravel
#define DONE_BIT                0x10  //Done condition
#define IBF_BIT                 0x20  //Character received from controller
#define TBE_BIT                 0x40  //Controller ready to receive a character
#define IRQ_BIT                 0x80  //Controller interrupt master enable
// done register bits
#define AXIS_X                  0x01
#define AXIS_Y                  0x02
#define AXIS_Z                  0x04
#define AXIS_T                  0x08
#define AXIS_U                  0x10
#define AXIS_V                  0x20
#define AXIS_R                  0x40
#define AXIS_S                  0x80

// interesting shared memory offsets (from shared_mem base)
#define OMS_MEM_CARDNUM         0x00000000

// 64k Shared Memory Offsets
#define MEM_RT_MOTOR				0x00000000			//Real Time Motor Position
	#define MEM_X_OFFSET				0x00					// Offset to X axis data
	#define MEM_Y_OFFSET				0x04					// Offset to Y axis data
	#define MEM_Z_OFFSET				0x08					// Offset to Z axis data
	#define MEM_T_OFFSET				0x0C					// Offset to T axis data
	#define MEM_U_OFFSET				0x10					// Offset to U axis data
	#define MEM_V_OFFSET				0x14					// Offset to V axis data
	#define MEM_R_OFFSET				0x18					// Offset to R axis data
	#define MEM_S_OFFSET				0x1C					// Offset to S axis data
#define MEM_RT_ENCODER			0x00000020			//Real Time Encoder Position
	// Same offsets as OMS_MEM_RT_MOTOR
#define MEM_CAP_RQ_MBOX			0x00000050			//Position Capture Request Mailbox
	#define MEM_CAP_REQUEST			0x00000001		// Request position capture
	#define MEM_CAP_COMPLETE		0x00000000		// Capture complete
#define MEM_CAP_MOTOR				0x00000054			//Motor Capture Data
	// Same offsets as OMS_MEM_RT_MOTOR
#define MEM_CAP_ENCODER			0x00000074			//Encoder Capture Data
	// Same offsets as OMS_MEM_RT_MOTOR
#define MEM_OUT_BINARY			0x00000900			//Outbound Binary Transfer Buffer
#define MEM_IN_BINARY				0x00000D00			//Inbound Binary Transfer Buffer
#define MEM_CAPTURE_TBL			0x00001540			//Position Capture Tables
	#define MEM_CAP_1						0x0000				// Table 1 Offset
	#define MEM_CAP_2						0x0150				// Table 2 Offset
	#define MEM_CAP_3						0x0328				// Table 3 Offset
	#define MEM_CAP_4						0x0978				// Table 4 Offset
	#define MEM_CAP_5						0x0CA0				// Table 5 Offset
	#define MEM_CAP_6						0x0FC8				// Table 6 Offset
	#define MEM_CAP_7						0x12F0				// Table 7 Offset
	#define MEM_CAP_8						0x1618				// Table 8 Offset
	
	#define MEM_CAP_INSERT			0x0000				// Insert Index Offset
	#define MEM_CAP_PROCESS			0x0004				// Process Index Offset
	#define MEM_CAP_BUFFER			0x0008				// Ring Buffer Offset
#define MEM_PROFILE_1				0x00004000			//Motion Profile Transfer Buffer 1
	#define MEM_PROF						0x0000				// Profile Buffer
	#define MEM_PROF_STATUS			0x0004				// Profile Buffer Status
	#define MEM_PROF_SEQNUM			0x0008				// Profile Buffer Sequence Number
	#define MEM_PROF_DATA				0x000C				// Profile Buffer Data
#define MEM_PROFILE_2				0x0000A000			//Motion Profile Transfer Buffer 2
	//same offsets as OMS_MEM_PROFILE_1 above

// 512k Shared Memory Offsets
#define MEM_VECTOR_INSERT		0x00000000			//Vector Mode Ring Buffer Insert Index
#define MEM_VECTOR_PROCESS	0x00000004			//Vector Mode Ring Buffer Process Index
#define MEM_VECTOR_BUFFER		0x00000008			//Vector Mode Ring Buffer (327,720 bytes)



#endif // __OMSMAXP_H_
