/* oms.h --- header file shared between driver and user-space
 *    programs.  Define the ioctl(2) API supported by the driver.
 *
 *  Copyright(c) 2003 Oregon Micro Systems, Inc.  All rights reserved.
 */

#ifndef __OMS_H_
#define __OMS_H_

#ifndef __OMS_CORE_H_
#include <sys/ioctl.h>
#endif

#define OMS_MAJOR_NUMBER 232  // from the "UNASSIGNED" region

// Some basic types we want to use
#ifndef BOOL
#define	BOOL	int
#endif
#ifndef TRUE
#define TRUE	1
#endif
#ifndef FALSE
#define FALSE	0
#endif

#define  SPACE                  0x20
#define  LF                     0x0A
#define  CR                     0x0D


#define OMS_IOC_TYP    'm'

struct oms_ioctl {
        unsigned char  *command;      //  IN
        unsigned int    command_len;  //  IN
        unsigned char  *response;     //  OUT
        unsigned int    response_len; //  IN and OUT
};

// IOCTL codes
#define IOCTL_OMS_GET_VERSION         _IOWR(OMS_IOC_TYP,  0, struct oms_ioctl)

#define IOCTL_OMS_COMMAND             _IOW(OMS_IOC_TYP,   1, struct oms_ioctl)
#define IOCTL_OMS_COMMAND_NONALPHA    _IOW(OMS_IOC_TYP,   2, struct oms_ioctl)
#define IOCTL_OMS_QUERY               _IOWR(OMS_IOC_TYP,  3, struct oms_ioctl)
#define IOCTL_OMS_QUERY_NONALPHA      _IOWR(OMS_IOC_TYP,  4, struct oms_ioctl)

#define IOCTL_OMS_READ_SHARED_MEM     _IOWR(OMS_IOC_TYP,  5, struct oms_ioctl)
#define IOCTL_OMS_WRITE_SHARED_MEM    _IOWR(OMS_IOC_TYP,  6, struct oms_ioctl)

#define IOCTL_OMS_READ_STATUS_FLAGS   _IOWR(OMS_IOC_TYP,  7, struct oms_ioctl)
#define IOCTL_OMS_CLEAR_STATUS_FLAGS  _IOW(OMS_IOC_TYP,   8, struct oms_ioctl)

#define IOCTL_OMS_READ_DONE_FLAGS     _IOWR(OMS_IOC_TYP,  9, struct oms_ioctl)
#define IOCTL_OMS_CLEAR_DONE_FLAGS    _IOW(OMS_IOC_TYP,  10, struct oms_ioctl)

#define IOCTL_OMS_READ_PLIMIT_FLAGS   _IOWR(OMS_IOC_TYP, 11, struct oms_ioctl)
#define IOCTL_OMS_CLEAR_PLIMIT_FLAGS  _IOW(OMS_IOC_TYP,  12, struct oms_ioctl)

#define IOCTL_OMS_READ_NLIMIT_FLAGS   _IOWR(OMS_IOC_TYP, 13, struct oms_ioctl)
#define IOCTL_OMS_CLEAR_NLIMIT_FLAGS  _IOW(OMS_IOC_TYP,  14, struct oms_ioctl)

#define IOCTL_OMS_READ_SLIP_FLAGS     _IOWR(OMS_IOC_TYP, 15, struct oms_ioctl)
#define IOCTL_OMS_CLEAR_SLIP_FLAGS    _IOW(OMS_IOC_TYP,  16, struct oms_ioctl)

#define IOCTL_OMS_READ_AXIS_POSITIONS _IOWR(OMS_IOC_TYP, 17, struct oms_ioctl)

#define IOCTL_OMS_CMD_BUFF_FREE       _IOWR(OMS_IOC_TYP, 18, struct oms_ioctl)

// NOTE: Card-specific code may define additional codes starting at:
#define CSIOCTL_BASE	100


// not used by shared library functions:  put driver in INTERACTIVE_MODE
// to support read/write/poll operations
//  Notes:  exclusive open enforced for a card in INTERACTIVE_MODE.  This
//  ioctl will fail (EBUSY) if the count of opens is not one.  Once a
//  card has been put in interactive mode, any further opens will fail
//  (EBUSY) until the 'owner' closes or calls EXIT.
#define IOCTL_OMS_ENTER_INTERACTIVE_MODE _IO(OMS_IOC_TYP, 200)
#define IOCTL_OMS_EXIT_INTERACTIVE_MODE _IO(OMS_IOC_TYP, 201)

// Should only be called after an upgrade
#define IOCTL_OMS_REINIT              _IO(OMS_IOC_TYP, 210)


#endif // __OMS_CORE_H_
